@@ -28,7 +28,7 @@ function (sradata, start = NULL, fixed = NULL, macroE = FALSE,
         sraMinuslogL(sradata = sradata, FUNtimeseries = sraTimeseries, 
             mu0 = mu0, logvarA0 = logvarA0, logvarE0 = logvarE0, 
             logNe = logNe, logn = logn, logvarM = logvarM, kc = kc, 
-            kg = kg, o = ifelse(is.na(o), mu0, o), s = s, logvarME = logvarME)
+            kg = kg, o = o, s = s, logvarME = logvarME)
     }
     fit <- mle(minuslogl = mlewrapper, start = start, fixed = fixed, 
         ...)
